@@ -12,7 +12,7 @@ public:
 
   virtual void bind(const cpp11::list& params) = 0;
 
-  virtual cpp11::writable::list get_column_info() = 0;
+  virtual cpp11::list get_column_info() = 0;
 
   virtual cpp11::list fetch(int n_max = -1) = 0;
 
@@ -21,4 +21,4 @@ public:
   virtual bool complete() const = 0;
 };
 
-#endif //RMARIADB_MARIARESULTIMPL_H
+#endif  // RMARIADB_MARIARESULTIMPL_H
